==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/prediction_service_get_cohort_look_ahead_response_200_predictions_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.cohort_look_ahead_prediction_as_of import CohortLookAheadPredictionAsOf
from ..models.prediction_service_get_cohort_look_ahead_response_200_predictions_item_scenario import (
    PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario,
)
from ..models.prediction_service_get_cohort_look_ahead_response_200_predictions_item_values_item import (
    PredictionService_GetCohortLookAheadResponse_200PredictionsItemValuesItem,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="PredictionService_GetCohortLookAheadResponse_200PredictionsItem"
)


@attr.s(auto_attribs=True)
class PredictionService_GetCohortLookAheadResponse_200PredictionsItem:
    """  """

    as_of: Union[CohortLookAheadPredictionAsOf, Unset] = UNSET
    scenario: Union[
        Unset, PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario
    ] = PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario.BASELINE
    symbol: Union[Unset, str] = UNSET
    values: Union[
        Unset,
        List[PredictionService_GetCohortLookAheadResponse_200PredictionsItemValuesItem],
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        as_of: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.as_of, Unset):
            as_of = self.as_of.to_dict()

        scenario: Union[
            Unset,
            PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario,
        ] = UNSET
        if not isinstance(self.scenario, Unset):
            scenario = self.scenario

        symbol = self.symbol
        values: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.values, Unset):
            values = []
            for values_item_data in self.values:
                values_item = values_item_data.to_dict()

                values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if as_of is not UNSET:
            field_dict["asOf"] = as_of
        if scenario is not UNSET:
            field_dict["scenario"] = scenario
        if symbol is not UNSET:
            field_dict["symbol"] = symbol
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        as_of: Union[CohortLookAheadPredictionAsOf, Unset] = UNSET
        _as_of = d.pop("asOf", UNSET)
        if not isinstance(_as_of, Unset):
            as_of = CohortLookAheadPredictionAsOf.from_dict(
                cast(Dict[str, Any], _as_of)
            )

        scenario = None
        _scenario = d.pop("scenario", UNSET)
        if _scenario is not None and _scenario is not UNSET:
            scenario = (
                PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario(
                    _scenario
                )
            )

        symbol = d.pop("symbol", UNSET)

        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = PredictionService_GetCohortLookAheadResponse_200PredictionsItemValuesItem.from_dict(
                values_item_data
            )

            values.append(values_item)

        prediction_service_get_cohort_look_ahead_response_200_predictions_item = cls(
            as_of=as_of,
            scenario=scenario,
            symbol=symbol,
            values=values,
        )

        prediction_service_get_cohort_look_ahead_response_200_predictions_item.additional_properties = (
            d
        )
        return prediction_service_get_cohort_look_ahead_response_200_predictions_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.259.0-py3-none-any.whl: infima_client/models/prediction_service_get_cohort_look_ahead_response_200_predictions_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.cohort_look_ahead_prediction_as_of import CohortLookAheadPredictionAsOf
from ..models.cohort_look_ahead_prediction_period import CohortLookAheadPredictionPeriod
from ..models.prediction_service_get_cohort_look_ahead_response_200_predictions_item_model import (
    PredictionService_GetCohortLookAheadResponse_200PredictionsItemModel,
)
from ..models.prediction_service_get_cohort_look_ahead_response_200_predictions_item_scenario import (
    PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario,
)
from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="PredictionService_GetCohortLookAheadResponse_200PredictionsItem"
)


@attr.s(auto_attribs=True)
class PredictionService_GetCohortLookAheadResponse_200PredictionsItem:
    """  """

    as_of: Union[CohortLookAheadPredictionAsOf, Unset] = UNSET
    model: Union[
        Unset, PredictionService_GetCohortLookAheadResponse_200PredictionsItemModel
    ] = PredictionService_GetCohortLookAheadResponse_200PredictionsItemModel.ALL
    num_components: Union[Unset, int] = UNSET
    scenario: Union[
        Unset, PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario
    ] = PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario.BASELINE
    symbol: Union[Unset, str] = UNSET
    values: Union[Unset, List[CohortLookAheadPredictionPeriod]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        as_of: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.as_of, Unset):
            as_of = self.as_of.to_dict()

        model: Union[
            Unset, PredictionService_GetCohortLookAheadResponse_200PredictionsItemModel
        ] = UNSET
        if not isinstance(self.model, Unset):
            model = self.model

        num_components = self.num_components
        scenario: Union[
            Unset,
            PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario,
        ] = UNSET
        if not isinstance(self.scenario, Unset):
            scenario = self.scenario

        symbol = self.symbol
        values: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.values, Unset):
            values = []
            for values_item_data in self.values:
                values_item = values_item_data.to_dict()

                values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if as_of is not UNSET:
            field_dict["asOf"] = as_of
        if model is not UNSET:
            field_dict["model"] = model
        if num_components is not UNSET:
            field_dict["numComponents"] = num_components
        if scenario is not UNSET:
            field_dict["scenario"] = scenario
        if symbol is not UNSET:
            field_dict["symbol"] = symbol
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        as_of: Union[CohortLookAheadPredictionAsOf, Unset] = UNSET
        _as_of = d.pop("asOf", UNSET)
        if not isinstance(_as_of, Unset):
            as_of = CohortLookAheadPredictionAsOf.from_dict(
                cast(Dict[str, Any], _as_of)
            )

        model = None
        _model = d.pop("model", UNSET)
        if _model is not None and _model is not UNSET:
            model = (
                PredictionService_GetCohortLookAheadResponse_200PredictionsItemModel(
                    _model
                )
            )

        num_components = d.pop("numComponents", UNSET)

        scenario = None
        _scenario = d.pop("scenario", UNSET)
        if _scenario is not None and _scenario is not UNSET:
            scenario = (
                PredictionService_GetCohortLookAheadResponse_200PredictionsItemScenario(
                    _scenario
                )
            )

        symbol = d.pop("symbol", UNSET)

        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = CohortLookAheadPredictionPeriod.from_dict(values_item_data)

            values.append(values_item)

        prediction_service_get_cohort_look_ahead_response_200_predictions_item = cls(
            as_of=as_of,
            model=model,
            num_components=num_components,
            scenario=scenario,
            symbol=symbol,
            values=values,
        )

        prediction_service_get_cohort_look_ahead_response_200_predictions_item.additional_properties = (
            d
        )
        return prediction_service_get_cohort_look_ahead_response_200_predictions_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
